@@ -1,6 +1,6 @@
 /*************************************************************************
  *
- * $Id: trionan.c,v 1.11 2003/04/03 15:28:28 veillard Exp $
+ * $Id: trionan.c,v 1.12 2003/08/06 04:43:53 wbrack Exp $
  *
  * Copyright (C) 2001 Bjorn Reese <breese@users.sourceforge.net>
  *
@@ -108,7 +108,7 @@
  * Constants
  */
 
-static TRIO_CONST char rcsid[] = "@(#)$Id: trionan.c,v 1.11 2003/04/03 15:28:28 veillard Exp $";
+static TRIO_CONST char rcsid[] = "@(#)$Id: trionan.c,v 1.12 2003/08/06 04:43:53 wbrack Exp $";
 
 #if defined(USE_IEEE_754)
 
@@ -500,7 +500,8 @@ TRIO_ARGS1((number),
 #endif
 }
 
-
+#if 0
+	/* Temporary fix - this routine is not used anywhere */
 /**
    Check for finity.
 
@@ -542,6 +543,7 @@ TRIO_ARGS1((number),
 #endif
 }
 
+#endif
 
 /*
  * The sign of NaN is always false
@@ -729,6 +731,8 @@ TRIO_ARGS1((number),
   return is_negative;
 }
 
+#if 0
+	/* Temporary fix - this routine is not used in libxml */
 /**
    Examine the class of a number.
 
@@ -745,6 +749,7 @@ TRIO_ARGS1((number),
   return trio_fpclassify_and_signbit(number, &dummy);
 }
 
+#endif
 
 /** @} SpecialQuantities */
 
